Crate axvm_types

Crate axvm_types 

Shared base types for AxVM and virtualization capability components.

This crate intentionally contains only small value types and aliases. It is not a host capability API and must not depend on any OS-specific crate.

Structs

EmulatedDeviceConfig
A part of AxVMConfig, which represents the configuration of an emulated device for a virtual machine.
GuestPhysAddr
Guest physical address.
GuestVirtAddr
Guest virtual address.
PassThroughAddressConfig
A part of AxVMConfig, which represents the configuration of a pass-through address for a virtual machine.
PassThroughDeviceConfig
A part of AxVMConfig, which represents the configuration of a pass-through device for a virtual machine.
VmMemConfig
Configuration for a virtual machine memory region.

Enums

EmulatedDeviceType
The type of emulated device.
VMBootProtocol
Describes how a guest VM should enter its boot image.
VMInterruptMode
Specifies how the VM should handle interrupts and interrupt controllers.
VMType
A part of AxVMConfig, which represents guest VM type.
VmMemMappingType
The type of memory mapping used for VM memory regions.

Constants

MAX_VCPU_NUM
The maximum number of virtual CPUs supported in a virtual machine.

Type Aliases

AxVmError
Common AxVM error type.
AxVmResult
Common AxVM result type.
GuestPhysAddrRange
Guest physical address range.
GuestVirtAddrRange
Guest virtual address range.
HostPhysAddr
Host physical address.
HostVirtAddr
Host virtual address.
InterruptVector
Interrupt vector number injected into a guest.
VCpuId
Virtual CPU identifier within a VM.
VCpuSet
A set of virtual CPUs.
VMId
Virtual machine identifier.