pub enum VMInterruptMode {
NoIrq,
Emulated,
Passthrough,
}Expand description
Specifies how the VM should handle interrupts and interrupt controllers.
Variants
NoIrq
The VM will not handle interrupts, and the guest OS should not use interrupts.
Emulated
The VM will use the emulated interrupt controller to handle interrupts.
Passthrough
The VM will use the passthrough interrupt controller (including GPPT) to handle interrupts.