#[repr(u8)]pub enum VmMemMappingType {
MapAlloc = 0,
MapIdentical = 1,
MapReserved = 2,
}Expand description
The type of memory mapping used for VM memory regions.
Variants
MapAlloc = 0
The memory region is allocated by the VM monitor.
MapIdentical = 1
The memory region is identical to the host physical memory region.
MapReserved = 2
The memory region is reserved memory for the guest OS.