Crate axvm_types

Crate axvm_types 

Shared base types for AxVM and virtualization capability components.

This crate intentionally contains only small value types and aliases. It is not a host capability API and must not depend on any OS-specific crate.

Structs

EmulatedDeviceConfig
A part of AxVMConfig, which represents the configuration of an emulated device for a virtual machine.
GuestPhysAddr
Guest physical address.
GuestVirtAddr
Guest virtual address.
IrqLineId
Identifier of an interrupt line within a virtual machine.
MappingFlags
Generic memory mapping permissions and attributes exchanged between AxVM components.
NestedPageFaultInfo
Information about a nested guest page-table fault.
NestedPagingConfig
Architecture-specific nested paging configuration selected by AxVM.
PassThroughAddressConfig
A part of AxVMConfig, which represents the configuration of a pass-through address for a virtual machine.
PassThroughDeviceConfig
A part of AxVMConfig, which represents the configuration of a pass-through device for a virtual machine.
PassThroughPortConfig
A part of AxVMConfig, which represents a host I/O port range passed through to a virtual machine.
Port
The port number of an x86 I/O operation.
ReservedAddressConfig
A guest physical address range reserved from default passthrough mapping.
SysRegAddr
A system register address.
VmMemConfig
Configuration for a virtual machine memory region.

Enums

AccessWidth
The width of a guest bus access.
AddressSpacePolicy
Guest physical address space population policy.
EmulatedDeviceType
The type of emulated device.
InterruptTriggerMode
Interrupt trigger mode.
VMBootProtocol
Describes how a guest VM should enter its boot image.
VMInterruptMode
Specifies how the VM should handle interrupts and interrupt controllers.
VMType
A part of AxVMConfig, which represents guest VM type.
VmExit
Legacy/common normalized VM event.
VmMemMappingType
The type of memory mapping used for VM memory regions.
VmVcpuState
Execution state of an AxVM-owned vCPU wrapper.

Constants

MAX_VCPU_NUM
The maximum number of virtual CPUs supported in a virtual machine.

Traits

VmArchPerCpuOps
Architecture-specific per-CPU virtualization state consumed by AxVM.
VmArchVcpuOps
Architecture-specific vCPU operations consumed by AxVM.

Type Aliases

AxVmError
Common AxVM error type.
AxVmResult
Common AxVM result type.
GuestPhysAddrRange
Guest physical address range.
GuestVirtAddrRange
Guest virtual address range.
HostPhysAddr
Host physical address.
HostVirtAddr
Host virtual address.
InterruptVector
Interrupt vector number injected into a guest.
VCpuId
Virtual CPU identifier within a VM.
VCpuSet
A set of virtual CPUs.
VMId
Virtual machine identifier.