Shared base types for AxVM and virtualization capability components.
This crate intentionally contains only small value types and aliases. It is not a host capability API and must not depend on any OS-specific crate.
Structs
- Emulated
Device Config - A part of
AxVMConfig, which represents the configuration of an emulated device for a virtual machine. - Guest
Phys Addr - Guest physical address.
- Guest
Virt Addr - Guest virtual address.
- IrqLine
Id - Identifier of an interrupt line within a virtual machine.
- Mapping
Flags - Generic memory mapping permissions and attributes exchanged between AxVM components.
- Nested
Page Fault Info - Information about a nested guest page-table fault.
- Nested
Paging Config - Architecture-specific nested paging configuration selected by AxVM.
- Pass
Through Address Config - A part of
AxVMConfig, which represents the configuration of a pass-through address for a virtual machine. - Pass
Through Device Config - A part of
AxVMConfig, which represents the configuration of a pass-through device for a virtual machine. - Pass
Through Port Config - A part of
AxVMConfig, which represents a host I/O port range passed through to a virtual machine. - Port
- The port number of an x86 I/O operation.
- Reserved
Address Config - A guest physical address range reserved from default passthrough mapping.
- SysReg
Addr - A system register address.
- VmMem
Config - Configuration for a virtual machine memory region.
Enums
- Access
Width - The width of a guest bus access.
- Address
Space Policy - Guest physical address space population policy.
- Emulated
Device Type - The type of emulated device.
- Interrupt
Trigger Mode - Interrupt trigger mode.
- VMBoot
Protocol - Describes how a guest VM should enter its boot image.
- VMInterrupt
Mode - Specifies how the VM should handle interrupts and interrupt controllers.
- VMType
- A part of
AxVMConfig, which represents guest VM type. - VmExit
- Legacy/common normalized VM event.
- VmMem
Mapping Type - The type of memory mapping used for VM memory regions.
- VmVcpu
State - Execution state of an AxVM-owned vCPU wrapper.
Constants
- MAX_
VCPU_ NUM - The maximum number of virtual CPUs supported in a virtual machine.
Traits
- VmArch
PerCpu Ops - Architecture-specific per-CPU virtualization state consumed by AxVM.
- VmArch
Vcpu Ops - Architecture-specific vCPU operations consumed by AxVM.
Type Aliases
- AxVm
Error - Common AxVM error type.
- AxVm
Result - Common AxVM result type.
- Guest
Phys Addr Range - Guest physical address range.
- Guest
Virt Addr Range - Guest virtual address range.
- Host
Phys Addr - Host physical address.
- Host
Virt Addr - Host virtual address.
- Interrupt
Vector - Interrupt vector number injected into a guest.
- VCpuId
- Virtual CPU identifier within a VM.
- VCpuSet
- A set of virtual CPUs.
- VMId
- Virtual machine identifier.