Shared base types for AxVM and virtualization capability components.
This crate intentionally contains only small value types and aliases. It is not a host capability API and must not depend on any OS-specific crate.
Structs
- Emulated
Device Config - A part of
AxVMConfig, which represents the configuration of an emulated device for a virtual machine. - Guest
Phys Addr - Guest physical address.
- Guest
Virt Addr - Guest virtual address.
- Pass
Through Address Config - A part of
AxVMConfig, which represents the configuration of a pass-through address for a virtual machine. - Pass
Through Device Config - A part of
AxVMConfig, which represents the configuration of a pass-through device for a virtual machine. - VmMem
Config - Configuration for a virtual machine memory region.
Enums
- Emulated
Device Type - The type of emulated device.
- VMBoot
Protocol - Describes how a guest VM should enter its boot image.
- VMInterrupt
Mode - Specifies how the VM should handle interrupts and interrupt controllers.
- VMType
- A part of
AxVMConfig, which represents guest VM type. - VmMem
Mapping Type - The type of memory mapping used for VM memory regions.
Constants
- MAX_
VCPU_ NUM - The maximum number of virtual CPUs supported in a virtual machine.
Type Aliases
- AxVm
Error - Common AxVM error type.
- AxVm
Result - Common AxVM result type.
- Guest
Phys Addr Range - Guest physical address range.
- Guest
Virt Addr Range - Guest virtual address range.
- Host
Phys Addr - Host physical address.
- Host
Virt Addr - Host virtual address.
- Interrupt
Vector - Interrupt vector number injected into a guest.
- VCpuId
- Virtual CPU identifier within a VM.
- VCpuSet
- A set of virtual CPUs.
- VMId
- Virtual machine identifier.