pub enum InterruptTriggerMode {
EdgeTriggered,
LevelTriggered,
}Expand description
Interrupt trigger mode.
Represents the trigger mode of an interrupt in a platform-neutral way. Architectures that do not distinguish between edge and level triggering can ignore this parameter.
Variants